Documentation
¶
Index ¶
- Variables
- type Account
- func (*Account) Descriptor() ([]byte, []int)deprecated
- func (x *Account) GetCustomId() string
- func (x *Account) GetDevices() []*AccountDevice
- func (x *Account) GetDisableTime() *timestamppb.Timestamp
- func (x *Account) GetEmail() string
- func (x *Account) GetUser() *User
- func (x *Account) GetVerifyTime() *timestamppb.Timestamp
- func (x *Account) GetWallet() string
- func (*Account) ProtoMessage()
- func (x *Account) ProtoReflect() protoreflect.Message
- func (x *Account) Reset()
- func (x *Account) String() string
- type AccountDevice
- func (*AccountDevice) Descriptor() ([]byte, []int)deprecated
- func (x *AccountDevice) GetId() string
- func (x *AccountDevice) GetVars() map[string]string
- func (*AccountDevice) ProtoMessage()
- func (x *AccountDevice) ProtoReflect() protoreflect.Message
- func (x *AccountDevice) Reset()
- func (x *AccountDevice) String() string
- type Notification
- func (*Notification) Descriptor() ([]byte, []int)deprecated
- func (x *Notification) GetCode() int32
- func (x *Notification) GetContent() string
- func (x *Notification) GetCreateTime() *timestamppb.Timestamp
- func (x *Notification) GetId() string
- func (x *Notification) GetPersistent() bool
- func (x *Notification) GetSenderId() string
- func (x *Notification) GetSubject() string
- func (*Notification) ProtoMessage()
- func (x *Notification) ProtoReflect() protoreflect.Message
- func (x *Notification) Reset()
- func (x *Notification) String() string
- type Rpc
- type Session
- func (*Session) Descriptor() ([]byte, []int)deprecated
- func (x *Session) GetCreated() bool
- func (x *Session) GetRefreshToken() string
- func (x *Session) GetToken() string
- func (*Session) ProtoMessage()
- func (x *Session) ProtoReflect() protoreflect.Message
- func (x *Session) Reset()
- func (x *Session) String() string
- type SessionLogoutRequest
- func (*SessionLogoutRequest) Descriptor() ([]byte, []int)deprecated
- func (x *SessionLogoutRequest) GetRefreshToken() string
- func (x *SessionLogoutRequest) GetToken() string
- func (*SessionLogoutRequest) ProtoMessage()
- func (x *SessionLogoutRequest) ProtoReflect() protoreflect.Message
- func (x *SessionLogoutRequest) Reset()
- func (x *SessionLogoutRequest) String() string
- type SessionRefreshRequest
- func (*SessionRefreshRequest) Descriptor() ([]byte, []int)deprecated
- func (x *SessionRefreshRequest) GetToken() string
- func (x *SessionRefreshRequest) GetVars() map[string]string
- func (*SessionRefreshRequest) ProtoMessage()
- func (x *SessionRefreshRequest) ProtoReflect() protoreflect.Message
- func (x *SessionRefreshRequest) Reset()
- func (x *SessionRefreshRequest) String() string
- type User
- func (*User) Descriptor() ([]byte, []int)deprecated
- func (x *User) GetAppleId() string
- func (x *User) GetAvatarUrl() string
- func (x *User) GetCreateTime() *timestamppb.Timestamp
- func (x *User) GetDisplayName() string
- func (x *User) GetEdgeCount() int32
- func (x *User) GetFacebookId() string
- func (x *User) GetFacebookInstantGameId() string
- func (x *User) GetGamecenterId() string
- func (x *User) GetGoogleId() string
- func (x *User) GetId() string
- func (x *User) GetLangTag() string
- func (x *User) GetLocation() string
- func (x *User) GetMetadata() string
- func (x *User) GetOnline() bool
- func (x *User) GetSteamId() string
- func (x *User) GetTimezone() string
- func (x *User) GetUpdateTime() *timestamppb.Timestamp
- func (x *User) GetUsername() string
- func (*User) ProtoMessage()
- func (x *User) ProtoReflect() protoreflect.Message
- func (x *User) Reset()
- func (x *User) String() string
Constants ¶
This section is empty.
Variables ¶
var File_api_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Account ¶
type Account struct {
// The user object.
User *User `protobuf:"bytes,1,opt,name=user,proto3" json:"user,omitempty"`
// The user's wallet data.
Wallet string `protobuf:"bytes,2,opt,name=wallet,proto3" json:"wallet,omitempty"`
// The email address of the user.
Email string `protobuf:"bytes,3,opt,name=email,proto3" json:"email,omitempty"`
// The devices which belong to the user's account.
Devices []*AccountDevice `protobuf:"bytes,4,rep,name=devices,proto3" json:"devices,omitempty"`
// The custom id in the user's account.
CustomId string `protobuf:"bytes,5,opt,name=custom_id,json=customId,proto3" json:"custom_id,omitempty"`
// The UNIX time when the user's email was verified.
VerifyTime *timestamppb.Timestamp `protobuf:"bytes,6,opt,name=verify_time,json=verifyTime,proto3" json:"verify_time,omitempty"`
// The UNIX time when the user's account was disabled/banned.
DisableTime *timestamppb.Timestamp `protobuf:"bytes,7,opt,name=disable_time,json=disableTime,proto3" json:"disable_time,omitempty"`
// contains filtered or unexported fields
}
func (*Account) Descriptor
deprecated
func (*Account) GetCustomId ¶
func (*Account) GetDevices ¶
func (x *Account) GetDevices() []*AccountDevice
func (*Account) GetDisableTime ¶
func (x *Account) GetDisableTime() *timestamppb.Timestamp
func (*Account) GetVerifyTime ¶
func (x *Account) GetVerifyTime() *timestamppb.Timestamp
func (*Account) ProtoMessage ¶
func (*Account) ProtoMessage()
func (*Account) ProtoReflect ¶
func (x *Account) ProtoReflect() protoreflect.Message
type AccountDevice ¶
type AccountDevice struct {
// A device identifier. Should be obtained by a platform-specific device API.
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
// Extra information that will be bundled in the session token.
Vars map[string]string `` /* 149-byte string literal not displayed */
// contains filtered or unexported fields
}
Send a device to the server. Used with authenticate/link/unlink and user.
func (*AccountDevice) Descriptor
deprecated
func (*AccountDevice) Descriptor() ([]byte, []int)
Deprecated: Use AccountDevice.ProtoReflect.Descriptor instead.
func (*AccountDevice) GetId ¶
func (x *AccountDevice) GetId() string
func (*AccountDevice) GetVars ¶
func (x *AccountDevice) GetVars() map[string]string
func (*AccountDevice) ProtoMessage ¶
func (*AccountDevice) ProtoMessage()
func (*AccountDevice) ProtoReflect ¶
func (x *AccountDevice) ProtoReflect() protoreflect.Message
func (*AccountDevice) Reset ¶
func (x *AccountDevice) Reset()
func (*AccountDevice) String ¶
func (x *AccountDevice) String() string
type Notification ¶
type Notification struct {
// ID of the Notification.
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
// Subject of the notification.
Subject string `protobuf:"bytes,2,opt,name=subject,proto3" json:"subject,omitempty"`
// Content of the notification in JSON.
Content string `protobuf:"bytes,3,opt,name=content,proto3" json:"content,omitempty"`
// Category code for this notification.
Code int32 `protobuf:"varint,4,opt,name=code,proto3" json:"code,omitempty"`
// ID of the sender, if a user. Otherwise 'null'.
SenderId string `protobuf:"bytes,5,opt,name=sender_id,json=senderId,proto3" json:"sender_id,omitempty"`
// The UNIX time when the notification was created.
CreateTime *timestamppb.Timestamp `protobuf:"bytes,6,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
// True if this notification was persisted to the database.
Persistent bool `protobuf:"varint,7,opt,name=persistent,proto3" json:"persistent,omitempty"`
// contains filtered or unexported fields
}
A notification in the server.
func (*Notification) Descriptor
deprecated
func (*Notification) Descriptor() ([]byte, []int)
Deprecated: Use Notification.ProtoReflect.Descriptor instead.
func (*Notification) GetCode ¶
func (x *Notification) GetCode() int32
func (*Notification) GetContent ¶
func (x *Notification) GetContent() string
func (*Notification) GetCreateTime ¶
func (x *Notification) GetCreateTime() *timestamppb.Timestamp
func (*Notification) GetId ¶
func (x *Notification) GetId() string
func (*Notification) GetPersistent ¶
func (x *Notification) GetPersistent() bool
func (*Notification) GetSenderId ¶
func (x *Notification) GetSenderId() string
func (*Notification) GetSubject ¶
func (x *Notification) GetSubject() string
func (*Notification) ProtoMessage ¶
func (*Notification) ProtoMessage()
func (*Notification) ProtoReflect ¶
func (x *Notification) ProtoReflect() protoreflect.Message
func (*Notification) Reset ¶
func (x *Notification) Reset()
func (*Notification) String ¶
func (x *Notification) String() string
type Rpc ¶
type Rpc struct {
// The identifier of the function.
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
// The payload of the function which must be a JSON object.
Payload string `protobuf:"bytes,2,opt,name=payload,proto3" json:"payload,omitempty"`
// The authentication key used when executed as a non-client HTTP request.
HttpKey string `protobuf:"bytes,3,opt,name=http_key,json=httpKey,proto3" json:"http_key,omitempty"`
// contains filtered or unexported fields
}
Execute an Lua function on the server.
func (*Rpc) Descriptor
deprecated
func (*Rpc) GetHttpKey ¶
func (*Rpc) GetPayload ¶
func (*Rpc) ProtoMessage ¶
func (*Rpc) ProtoMessage()
func (*Rpc) ProtoReflect ¶
func (x *Rpc) ProtoReflect() protoreflect.Message
type Session ¶
type Session struct {
// True if the corresponding account was just created, false otherwise.
Created bool `protobuf:"varint,1,opt,name=created,proto3" json:"created,omitempty"`
// Authentication credentials.
Token string `protobuf:"bytes,2,opt,name=token,proto3" json:"token,omitempty"`
// Refresh token that can be used for session token renewal.
RefreshToken string `protobuf:"bytes,3,opt,name=refresh_token,json=refreshToken,proto3" json:"refresh_token,omitempty"`
// contains filtered or unexported fields
}
A user's session used to authenticate messages.
func (*Session) Descriptor
deprecated
func (*Session) GetCreated ¶
func (*Session) GetRefreshToken ¶
func (*Session) ProtoMessage ¶
func (*Session) ProtoMessage()
func (*Session) ProtoReflect ¶
func (x *Session) ProtoReflect() protoreflect.Message
type SessionLogoutRequest ¶
type SessionLogoutRequest struct {
// Session token to log out.
Token string `protobuf:"bytes,1,opt,name=token,proto3" json:"token,omitempty"`
// Refresh token to invalidate.
RefreshToken string `protobuf:"bytes,2,opt,name=refresh_token,json=refreshToken,proto3" json:"refresh_token,omitempty"`
// contains filtered or unexported fields
}
Log out a session, invalidate a refresh token, or log out all sessions/refresh tokens for a user.
func (*SessionLogoutRequest) Descriptor
deprecated
func (*SessionLogoutRequest) Descriptor() ([]byte, []int)
Deprecated: Use SessionLogoutRequest.ProtoReflect.Descriptor instead.
func (*SessionLogoutRequest) GetRefreshToken ¶
func (x *SessionLogoutRequest) GetRefreshToken() string
func (*SessionLogoutRequest) GetToken ¶
func (x *SessionLogoutRequest) GetToken() string
func (*SessionLogoutRequest) ProtoMessage ¶
func (*SessionLogoutRequest) ProtoMessage()
func (*SessionLogoutRequest) ProtoReflect ¶
func (x *SessionLogoutRequest) ProtoReflect() protoreflect.Message
func (*SessionLogoutRequest) Reset ¶
func (x *SessionLogoutRequest) Reset()
func (*SessionLogoutRequest) String ¶
func (x *SessionLogoutRequest) String() string
type SessionRefreshRequest ¶
type SessionRefreshRequest struct {
// Refresh token.
Token string `protobuf:"bytes,1,opt,name=token,proto3" json:"token,omitempty"`
// Extra information that will be bundled in the session token.
Vars map[string]string `` /* 149-byte string literal not displayed */
// contains filtered or unexported fields
}
Authenticate against the server with a refresh token.
func (*SessionRefreshRequest) Descriptor
deprecated
func (*SessionRefreshRequest) Descriptor() ([]byte, []int)
Deprecated: Use SessionRefreshRequest.ProtoReflect.Descriptor instead.
func (*SessionRefreshRequest) GetToken ¶
func (x *SessionRefreshRequest) GetToken() string
func (*SessionRefreshRequest) GetVars ¶
func (x *SessionRefreshRequest) GetVars() map[string]string
func (*SessionRefreshRequest) ProtoMessage ¶
func (*SessionRefreshRequest) ProtoMessage()
func (*SessionRefreshRequest) ProtoReflect ¶
func (x *SessionRefreshRequest) ProtoReflect() protoreflect.Message
func (*SessionRefreshRequest) Reset ¶
func (x *SessionRefreshRequest) Reset()
func (*SessionRefreshRequest) String ¶
func (x *SessionRefreshRequest) String() string
type User ¶
type User struct {
// The id of the user's account.
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
// The username of the user's account.
Username string `protobuf:"bytes,2,opt,name=username,proto3" json:"username,omitempty"`
// The display name of the user.
DisplayName string `protobuf:"bytes,3,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
// A URL for an avatar image.
AvatarUrl string `protobuf:"bytes,4,opt,name=avatar_url,json=avatarUrl,proto3" json:"avatar_url,omitempty"`
// The language expected to be a tag which follows the BCP-47 spec.
LangTag string `protobuf:"bytes,5,opt,name=lang_tag,json=langTag,proto3" json:"lang_tag,omitempty"`
// The location set by the user.
Location string `protobuf:"bytes,6,opt,name=location,proto3" json:"location,omitempty"`
// The timezone set by the user.
Timezone string `protobuf:"bytes,7,opt,name=timezone,proto3" json:"timezone,omitempty"`
// Additional information stored as a JSON object.
Metadata string `protobuf:"bytes,8,opt,name=metadata,proto3" json:"metadata,omitempty"`
// The Facebook id in the user's account.
FacebookId string `protobuf:"bytes,9,opt,name=facebook_id,json=facebookId,proto3" json:"facebook_id,omitempty"`
// The Google id in the user's account.
GoogleId string `protobuf:"bytes,10,opt,name=google_id,json=googleId,proto3" json:"google_id,omitempty"`
// The Apple Game Center in of the user's account.
GamecenterId string `protobuf:"bytes,11,opt,name=gamecenter_id,json=gamecenterId,proto3" json:"gamecenter_id,omitempty"`
// The Steam id in the user's account.
SteamId string `protobuf:"bytes,12,opt,name=steam_id,json=steamId,proto3" json:"steam_id,omitempty"`
// Indicates whether the user is currently online.
Online bool `protobuf:"varint,13,opt,name=online,proto3" json:"online,omitempty"`
// Number of related edges to this user.
EdgeCount int32 `protobuf:"varint,14,opt,name=edge_count,json=edgeCount,proto3" json:"edge_count,omitempty"`
// The UNIX time when the user was created.
CreateTime *timestamppb.Timestamp `protobuf:"bytes,15,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
// The UNIX time when the user was last updated.
UpdateTime *timestamppb.Timestamp `protobuf:"bytes,16,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
// The Facebook Instant Game ID in the user's account.
FacebookInstantGameId string `` /* 129-byte string literal not displayed */
// The Apple Sign In ID in the user's account.
AppleId string `protobuf:"bytes,18,opt,name=apple_id,json=appleId,proto3" json:"apple_id,omitempty"`
// contains filtered or unexported fields
}
A user in the server.
func (*User) Descriptor
deprecated
func (*User) GetAppleId ¶
func (*User) GetAvatarUrl ¶
func (*User) GetCreateTime ¶
func (x *User) GetCreateTime() *timestamppb.Timestamp
func (*User) GetDisplayName ¶
func (*User) GetEdgeCount ¶
func (*User) GetFacebookId ¶
func (*User) GetFacebookInstantGameId ¶
func (*User) GetGamecenterId ¶
func (*User) GetGoogleId ¶
func (*User) GetLangTag ¶
func (*User) GetLocation ¶
func (*User) GetMetadata ¶
func (*User) GetSteamId ¶
func (*User) GetTimezone ¶
func (*User) GetUpdateTime ¶
func (x *User) GetUpdateTime() *timestamppb.Timestamp
func (*User) GetUsername ¶
func (*User) ProtoMessage ¶
func (*User) ProtoMessage()
func (*User) ProtoReflect ¶
func (x *User) ProtoReflect() protoreflect.Message
Click to show internal directories.
Click to hide internal directories.